@@ -1,6 +1,8 @@
 from json_cpp import JsonObject
 from cellworld import *
 from datetime import datetime
+from uuid import uuid1
+
 
 class StartExperimentRequest(JsonObject):
     def __init__(self, prefix: str = "", suffix: str = "", world: World_info = None, subject_name: str = "", duration: int = 0):
@@ -13,26 +15,6 @@ class StartExperimentRequest(JsonObject):
         self.duration = duration
 
 
-class ResumeExperimentRequest(JsonObject):
-    def __init__(self, experiment_name: str = "", duration_extension: int = 0):
-        self.experiment_name = experiment_name
-        self.duration_extension = duration_extension
-
-
-class ResumeExperimentResponse(JsonObject):
-    def __init__(self, experiment_name: str = "", start_date: datetime = None, world: World_info = None, subject_name: str = "", duration: int = 0, episode_count: int = 0):
-        self.experiment_name = experiment_name
-        if not start_date:
-            start_date = datetime.now()
-        self.start_date = start_date
-        if not world:
-            world = World_info()
-        self.world = world
-        self.subject_name = subject_name
-        self.duration = duration
-        self.episode_count = episode_count
-
-
 class StartExperimentResponse(JsonObject):
     def __init__(self, experiment_name: str = "", start_date: datetime = None, world: World_info = None, subject_name: str = "", duration: int =0):
         self.experiment_name = experiment_name
